@@ -20,12 +20,20 @@
 
 #ifndef __HTML_H_
 #define __HTML_H_
+void insert_char_cb(GtkWidget * widget, gint data);
 void general_html_cb(GtkWidget * widget, gpointer data);
 void insert_time_cb(GtkWidget * widget, gpointer data);
 void quickanchor_cb(GtkWidget * widget, gpointer data);
 void block_tag_edit_cb(gint type, GtkWidget *widget, gpointer data);
+void p_dialog(GtkWidget * widget, gpointer data);
 void div_dialog(GtkWidget *widget, gpointer data);
 void span_dialog(GtkWidget * widget, gpointer data);
+void h1_dialog(GtkWidget * widget, gpointer data);
+void h2_dialog(GtkWidget * widget, gpointer data);
+void h3_dialog(GtkWidget * widget, gpointer data);
+void h4_dialog(GtkWidget * widget, gpointer data);
+void h5_dialog(GtkWidget * widget, gpointer data);
+void h6_dialog(GtkWidget * widget, gpointer data);
 void quickrule_cb(GtkWidget * widget, gpointer data);
 void quickstart_cb(GtkWidget * widget, gpointer data);
 void body_cb(GtkWidget * widget, gpointer data);
