@@ -21,6 +21,18 @@
 #ifndef __HTML_DIAG_H_
 #define __HTML_DIAG_H_
 
+typedef struct {
+	GList *classlist;
+	GList *colorlist;
+	GList *targetlist;
+	GList *urllist;
+	GList *fontlist;
+	GList *dtd_cblist;
+	GList *headerlist;
+	GList *positionlist;
+} Trecent_attribs;
+extern Trecent_attribs recent_attribs;
+
 typedef struct {
 	GtkWidget *src;
 	GtkWidget *dest;
@@ -36,12 +48,12 @@ typedef struct {
 typedef struct {
 	GList *taglist;
 	gint pos;
-	gint len;
+	gint end;
 } Ttagpopup;
 
 typedef struct {
 	gint pos;
-	gint len;
+	gint end;
 } Treplacerange;
 
 /* the frame wizard uses dynamic widgets, this value should be lower 
@@ -60,12 +72,15 @@ typedef struct {
 	GtkWidget *spin[8];
 	GtkWidget *check[8];
 	GtkWidget *clist[4];
+	GtkWidget *text[1];
 	Treplacerange range;
+	GtkTextMark *mark_ins;
+	GtkTextMark *mark_sel;
 	Tphpvarins php_var_ins;
 	Tdocument *doc;
 } Thtml_diag;
 
-void html_diag_destroy_cb(GtkWidget * widget, GdkEvent *event,  Thtml_diag *dg);
+void html_diag_destroy_cb(GtkWidget * widget, Thtml_diag *dg);
 
 void html_diag_cancel_clicked_cb(GtkWidget *widget, gpointer data);
 
