@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "default_include.h"
+#include <gtk/gtk.h>
 
 #include <string.h>
 
@@ -29,7 +29,7 @@
 #include "html_diag.h" /* html_diag functions */
 #include "html_form.h" /* myself */
 #include "stringlist.h" /* add to stringlist */
-#include "pixmaps.h" /* new_pixmap() */
+#include "pixmap.h" /* new_pixmap() */
 #include "gtk_easy.h"  /* entry_with_text and stuff */
 #include "document.h" /* insert_dbl_text */
 
@@ -72,10 +72,10 @@ GtkWidget *php_var_but(GtkWidget *src, GtkWidget *dest, Thtml_diag *dg, gint typ
 	dg->php_var_ins.dest = dest;
 	dg->php_var_ins.type = type;
 	returnwid = gtk_button_new();
-	pixmap = new_pixmap(173, dg->dialog->window, NULL);
+	pixmap = new_pixmap(84);
 	gtk_widget_show(pixmap);
 	gtk_container_add(GTK_CONTAINER(returnwid), pixmap);
-	gtk_signal_connect(GTK_OBJECT(returnwid), "clicked", php_var_insert_cb, dg);
+	gtk_signal_connect(GTK_OBJECT(returnwid), "clicked", G_CALLBACK(php_var_insert_cb), dg);
 	gtk_widget_show(returnwid);
 	return returnwid;
 }
@@ -103,15 +103,15 @@ static void formok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	main_v->current_project.targetlist = add_entry_to_stringlist(main_v->current_project.targetlist, GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry));
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</FORM>"));
+	recent_attribs.targetlist = add_entry_to_stringlist(recent_attribs.targetlist, GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</FORM>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -131,12 +131,12 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 
 	dgtable = html_diag_table_in_vbox(dg, 4, 10);
 
-	main_v->current_project.urllist = add_to_stringlist(main_v->current_project.urllist, "<?php echo $SCRIPT_NAME ?>");
-	main_v->current_project.urllist = add_to_stringlist(main_v->current_project.urllist, "'.$SCRIPT_NAME.'");
+	recent_attribs.urllist = add_to_stringlist(recent_attribs.urllist, "<?php echo $SCRIPT_NAME ?>");
+	recent_attribs.urllist = add_to_stringlist(recent_attribs.urllist, "'.$SCRIPT_NAME.'");
 	{
 	GList *rel_link_list, *tmplist;
-	rel_link_list = generate_relative_doc_list();
-	tmplist = duplicate_stringlist(main_v->current_project.urllist, 1);
+	rel_link_list = NULL /*generate_relative_doc_list()*/;
+	tmplist = duplicate_stringlist(recent_attribs.urllist, 1);
 	rel_link_list = g_list_concat(tmplist, rel_link_list);
 
 	dg->combo[4] = combo_with_popdown(tagvalues[0], rel_link_list, 1);
@@ -144,7 +144,7 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	free_stringlist(rel_link_list);
 	}
 	
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Action")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Action:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 1, 8, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), file_but_new(GTK_WIDGET(GTK_COMBO(dg->combo[4])->entry), dg->dialog, 0), 8, 10, 0, 1);
 	
@@ -152,7 +152,7 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	methodlist = g_list_append(methodlist, "POST");
 	dg->combo[1] = combo_with_popdown(tagvalues[1], methodlist, 1);
 	g_list_free(methodlist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Method")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("Metho_d:"), dg->combo[1], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[1])), 1, 2, 1, 2);
 
 	/* I need to add more types */
@@ -161,21 +161,21 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	enctypelist = g_list_append(enctypelist, "text/plain");
 	dg->combo[2] = combo_with_popdown(tagvalues[2], enctypelist, 1);
 	g_list_free(enctypelist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Enctype")), 3, 4, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Enctype:"), dg->combo[2], 0, 0.5, dgtable, 3, 4, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(dg->combo[2]), 4, 10, 1, 2);
 
-	main_v->current_project.targetlist = add_to_stringlist(main_v->current_project.targetlist, "_top");
-	main_v->current_project.targetlist = add_to_stringlist(main_v->current_project.targetlist, "_blank");
-	main_v->current_project.targetlist = add_to_stringlist(main_v->current_project.targetlist, "_parent");
-	dg->combo[3] = combo_with_popdown(tagvalues[3], main_v->current_project.targetlist, 1);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Target")), 0, 1, 2, 3);
+	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_top");
+	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_blank");
+	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_parent");
+	dg->combo[3] = combo_with_popdown(tagvalues[3], recent_attribs.targetlist, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Target:"), dg->combo[3], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 1, 10, 2, 3);
 
 	dg->entry[2] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 12, 3, 4);
 
-	html_diag_finish(dg, GTK_SIGNAL_FUNC(formok_lcb));
+	html_diag_finish(dg, G_CALLBACK(formok_lcb));
 
 	if (custom)	g_free(custom);
 
@@ -193,14 +193,14 @@ static void textareaok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</TEXTAREA>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</TEXTAREA>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void textareadialog_cb(GtkWidget * widget, gpointer data)
@@ -214,25 +214,25 @@ void textareadialog_cb(GtkWidget * widget, gpointer data)
 	dg = html_diag_new(_("Text area"));
 	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
 
-	dgtable = html_diag_table_in_vbox(dg, 5, 10);
+	dgtable = html_diag_table_in_vbox(dg, 4, 10);
 
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->spin[1] = spinbut_with_value(tagvalues[2], 0, 500, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Rows")), 0, 1, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 1, 2, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Rows:"), dg->spin[1], 0, 0.5, dgtable, 0, 1, 1, 2);
 
 	dg->spin[2] = spinbut_with_value(tagvalues[3], 0, 500, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[2], 1, 2, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Cols")), 0, 1, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[2], 1, 2, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Co_ls:"), dg->spin[2], 0, 0.5, dgtable, 0, 1, 2, 3);
 
 	dg->entry[2] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 4, 5);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 3, 4);
 
-	html_diag_finish(dg, textareaok_lcb);
+	html_diag_finish(dg, G_CALLBACK(textareaok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -254,13 +254,13 @@ static void textok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	}
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, NULL);
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -279,11 +279,11 @@ void textdialog_cb(GtkWidget * widget, gpointer data)
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[1], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 9, 1, 2);
 
 	varbut = php_var_but(dg->entry[1], dg->entry[2], dg, PHPFORM_TYPE_TEXT);
@@ -291,17 +291,17 @@ void textdialog_cb(GtkWidget * widget, gpointer data)
 
 	dg->spin[1] = spinbut_with_value(tagvalues[2], 0, 500, 1.0, 5.0);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Size")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Si_ze:"), dg->spin[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 
 	dg->spin[2] = spinbut_with_value(tagvalues[3], 0, 500, 1.0, 5.0);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[2], 1, 2, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Max Length")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Max _Length:"), dg->spin[2], 0, 0.5, dgtable, 0, 1, 3, 4);
 
 	dg->entry[3] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 4, 5);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 10, 4, 5);
 
-	html_diag_finish(dg, textok_lcb);
+	html_diag_finish(dg, G_CALLBACK(textok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -323,13 +323,13 @@ static void buttondialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	}
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, NULL);
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void buttondialog_cb(GtkWidget * widget, gpointer data) {
@@ -346,11 +346,11 @@ void buttondialog_cb(GtkWidget * widget, gpointer data) {
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[1], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 9, 1, 2);
 
 	tmplist = g_list_append(tmplist, "submit");
@@ -358,14 +358,14 @@ void buttondialog_cb(GtkWidget * widget, gpointer data) {
 	tmplist = g_list_append(tmplist, "button");
 	dg->combo[1] = combo_with_popdown(tagvalues[2], tmplist, 0);
 	g_list_free(tmplist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Type")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("_Type:"), dg->combo[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(dg->combo[1]), 1, 9, 2, 3);
 
 	dg->entry[3] = entry_with_text(custom, 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 9, 3, 4);
 
-	html_diag_finish(dg, buttondialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(buttondialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -384,13 +384,13 @@ static void hiddenok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	}
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, NULL);
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -408,18 +408,18 @@ void hiddendialog_cb(GtkWidget * widget, gpointer data)
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[1], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 1, 2);
 
 	dg->entry[3] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 10, 2, 3);
 
-	html_diag_finish(dg, hiddenok_lcb);
+	html_diag_finish(dg, G_CALLBACK(hiddenok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -440,13 +440,13 @@ static void radiodialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	}
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, NULL);
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -464,26 +464,26 @@ void radiodialog_cb(GtkWidget * widget, gpointer data)
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[1], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 1, 2);
 
 	dg->check[1] = gtk_check_button_new();
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Checked")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Chec_ked:"), dg->check[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 	parse_existence_for_dialog(tagvalues[2], dg->check[1]);
 
 	dg->entry[3] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 9, 3, 4);
 
 	varbut = php_var_but(dg->entry[1], dg->entry[3], dg, PHPFORM_TYPE_RADIO);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), varbut, 9, 10, 3, 4);
 
-	html_diag_finish(dg, radiodialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(radiodialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -504,13 +504,13 @@ static void checkdialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	}
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, NULL);
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, NULL);
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void checkdialog_cb(GtkWidget * widget, gpointer data)
@@ -527,26 +527,26 @@ void checkdialog_cb(GtkWidget * widget, gpointer data)
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[1], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 1, 2);
 
 	dg->check[1] = gtk_check_button_new();
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Checked")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Chec_ked:"), dg->check[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 	parse_existence_for_dialog(tagvalues[2], dg->check[1]);
 
 	dg->entry[3] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("_Custo_m:"), dg->entry[3], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[3], 1, 9, 3, 4);
 
 	varbut = php_var_but(dg->entry[1], dg->entry[3], dg, PHPFORM_TYPE_CHECK);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), varbut, 9, 10, 3, 4);
 
-	html_diag_finish(dg, checkdialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(checkdialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -563,13 +563,13 @@ static void selectdialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</SELECT>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</SELECT>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void selectdialog_cb(GtkWidget * widget, gpointer data)
@@ -586,23 +586,23 @@ void selectdialog_cb(GtkWidget * widget, gpointer data)
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Name")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Name:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->spin[1] = spinbut_with_value(tagvalues[1], 0, 100, 1.0, 5.0);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 1, 2, 1, 2);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Size")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("Si_ze:"), dg->spin[1], 0, 0.5, dgtable, 0, 1, 1, 2);
 
 	dg->check[1] = gtk_check_button_new();
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 1, 2, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Multiple selections")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Multiple _Selections:"), dg->check[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 	parse_existence_for_dialog(tagvalues[2], dg->check[1]);
 
 	dg->entry[2] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 3, 4);
 
-	html_diag_finish(dg, selectdialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(selectdialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -618,13 +618,13 @@ static void optiondialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</OPTION>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</OPTION>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void optiondialog_cb(GtkWidget * widget, gpointer data)
@@ -638,22 +638,22 @@ void optiondialog_cb(GtkWidget * widget, gpointer data)
 	dg = html_diag_new(_("Option"));
 	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
 
-	dgtable = html_diag_table_in_vbox(dg, 5, 10);
+	dgtable = html_diag_table_in_vbox(dg, 3, 10);
 
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Value")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Value:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
 	dg->entry[2] = entry_with_text(tagvalues[2], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Label")), 0, 1, 2, 3);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("_Label:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 10, 1, 2);
 
 	dg->check[1] = gtk_check_button_new();
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 1, 2, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Selected")), 0, 1, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 1, 2, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("_Selected:"), dg->check[1], 0, 0.5, dgtable, 0, 1, 2, 3);
 	parse_existence_for_dialog(tagvalues[2], dg->check[1]);
 
-	html_diag_finish(dg, optiondialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(optiondialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -667,13 +667,13 @@ static void optgroupdialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</OPTGROUP>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</OPTGROUP>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 void optgroupdialog_cb(GtkWidget * widget, gpointer data)
@@ -689,10 +689,10 @@ void optgroupdialog_cb(GtkWidget * widget, gpointer data)
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Label")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Label:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 10, 0, 1);
 
-	html_diag_finish(dg, optgroupdialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(optgroupdialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
