@@ -19,19 +19,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "default_include.h"
 
+#include <gtk/gtk.h>
 #include <string.h>
 
 #include "cap.h"  /* cap() */
 #include "bluefish.h"
-#include "coloursel.h" /* colorbut_new() */
+/*#include "coloursel.h"*/ /* colorbut_new() */
 #include "html_diag.h"
 #include "html_table.h"
 #include "html2.h" /* style_but_new */
-#include "init.h" 	/* positionlist */
+/*#include "init.h"*/ 	/* positionlist */
 #include "gtk_easy.h"
-/* #include "undo.h" */
 #include "document.h"
 #include "stringlist.h"
 
@@ -57,14 +56,14 @@ static void tabledialogok_lcb(GtkWidget * widget, Thtml_diag * dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</TABLE>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</TABLE>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -86,25 +85,25 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	dgtable = html_diag_table_in_vbox(dg, 5, 8);
 
 	dg->spin[1] = spinbut_with_value(tagvalues[0], 0, 100, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Cell Padding")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("Cell _Padding:"), dg->spin[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 1, 2, 0, 1);
 
 	dg->spin[3] = spinbut_with_value(tagvalues[1], 0, 100, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Cell Spacing")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("C_ell Spacing:"), dg->spin[3], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[3], 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[7], main_v->current_project.classlist, 1, 80);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Class")), 0, 1, 2, 3);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[7], recent_attribs.classlist, 1, 80);
+	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 1, 2, 2, 3);
 
 	dg->entry[2] = entry_with_text(tagvalues[8], 1024);
 	var_but = style_but_new(dg->entry[2], dg->dialog);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Style")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("St_yle:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 4, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), var_but, 4, 5, 3, 4);
 
 	dg->entry[1] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 4, 5);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 5, 4, 5);
 
 	alignlist = g_list_append(alignlist, "left");
@@ -112,7 +111,7 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	alignlist = g_list_append(alignlist, "center");
 	dg->combo[1] = combo_with_popdown_sized(tagvalues[3], alignlist, 0, 80);
 	g_list_free(alignlist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Align")), 2, 3, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("Ali_gn:"), dg->combo[1], 1, 0.5, dgtable, 2, 3, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[1], 3, 5, 0, 1);
 
   alignlist = NULL;
@@ -126,24 +125,24 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	dg->combo[2] = combo_with_popdown_sized(tagvalues[4], alignlist, 1, 80);
 	g_list_free(alignlist);
 
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Vertical Align")), 2, 3, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 1, 0.5, dgtable, 2, 3, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[2], 3, 5, 1, 2);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[5], main_v->current_project.colorlist, 1, 80);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[5], recent_attribs.colorlist, 1, 80);
 	var_but = color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Background Color")), 2, 3, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 0, 0.5, dgtable, 2, 3, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[3], 3, 4, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), var_but, 4, 5, 2, 3);
 
 	dg->spin[2] = spinbut_with_value(NULL, 0, 900, 1.0, 5.0);
 	dg->check[1] = gtk_check_button_new_with_label("%");
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_(" Width ")), 5, 6, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Width:"), dg->spin[2], 0, 0.5, dgtable, 5, 6, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[2], 6, 7, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 7, 8, 0, 1);
 	parse_integer_for_dialog(tagvalues[6], dg->spin[2], NULL, dg->check[1]);
 
 	dg->spin[4] = spinbut_with_value(tagvalues[2], 0, 100, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Border")), 5, 6, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("Bo_rder:"), dg->spin[4], 0, 0.5, dgtable, 5, 6, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[4], 6, 8, 1, 2);
 
 	popuplist = g_list_append(NULL, "");
@@ -157,7 +156,7 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	popuplist = g_list_append(popuplist, "box");
 	popuplist = g_list_append(popuplist, "border");
 	dg->combo[5] = combo_with_popdown_sized(tagvalues[10], popuplist, 0, 80);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Frame")), 5, 6, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("_Frame:"), dg->combo[5], 0, 0.5, dgtable, 5, 6, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[5], 6, 8, 2, 3);
 	g_list_free(popuplist);
 
@@ -168,11 +167,11 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	popuplist = g_list_append(popuplist, "cols");
 	popuplist = g_list_append(popuplist, "all");
 	dg->combo[6] = combo_with_popdown_sized(tagvalues[9], popuplist, 0, 80);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Rules")), 5, 6, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("R_ules:"), dg->combo[6], 0, 0.5, dgtable, 5, 6, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[6], 6, 8, 3, 4);
 	g_list_free(popuplist);
 
-	html_diag_finish(dg, tabledialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(tabledialogok_lcb));
 	
 	if (custom)	g_free(custom);
 }
@@ -192,13 +191,13 @@ static void tablerowdialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
-		doc_insert_dbl_text(dg->doc, finalstring, cap("</TR>"));
+	if (dg->range.end == -1) {
+		doc_insert_two_strings(dg->doc, finalstring, cap("</TR>"));
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 
@@ -223,7 +222,7 @@ void tablerowdialog_cb(GtkWidget * widget, gpointer data)
 	alignlist = g_list_insert(alignlist, "center", 2);
 	dg->combo[1] = combo_with_popdown_sized(tagvalues[0], alignlist, 0, 90);
 	g_list_free(alignlist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Align")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("Ali_gn:"), dg->combo[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(dg->combo[1]), 1, 2, 0, 1);
 
   alignlist = NULL;
@@ -237,30 +236,30 @@ void tablerowdialog_cb(GtkWidget * widget, gpointer data)
 	dg->combo[2] = combo_with_popdown_sized(tagvalues[1], alignlist, 0, 90);
 	g_list_free(alignlist);
 
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("VAlign")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[2])), 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[3], main_v->current_project.classlist, 1, 90);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Class")), 2, 3, 0, 1);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[3], recent_attribs.classlist, 1, 90);
+	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 1, 0.5, dgtable, 2, 3, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 3, 5, 0, 1);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[2], main_v->current_project.colorlist, 1, 90);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[2], recent_attribs.colorlist, 1, 90);
 	color_but = color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Background Color")), 2, 3, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 0, 0.5, dgtable, 2, 3, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 3, 4, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(color_but), 4, 5, 1, 2);
 
 	dg->entry[2] = entry_with_text(tagvalues[4], 1024);
 	var_but = style_but_new(dg->entry[2], dg->dialog);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Style")), 0, 1, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("St_yle:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 4, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), var_but, 4, 5, 2, 3);
 
 	dg->entry[1] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 5, 3, 4);
 
-	html_diag_finish(dg, tablerowdialogok_lcb);
+	html_diag_finish(dg, G_CALLBACK(tablerowdialogok_lcb));
 
 	if (custom)	g_free(custom);
 }
@@ -288,17 +287,17 @@ static void table_head_and_data_dialogok_lcb(gint type, GtkWidget * widget, Thtm
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	if (dg->range.len == -1) {
+	if (dg->range.end == -1) {
 		if (type == 1) {
-			doc_insert_dbl_text(dg->doc, finalstring, cap("</TD>"));
+			doc_insert_two_strings(dg->doc, finalstring, cap("</TD>"));
 		} else {
-			doc_insert_dbl_text(dg->doc, finalstring, cap("</TH>"));
+			doc_insert_two_strings(dg->doc, finalstring, cap("</TH>"));
 		}
 	} else {
-		replace_text(finalstring, dg->range.pos, dg->range.len);
+		doc_replace_text(dg->doc, finalstring, dg->range.pos, dg->range.end);
 	}
 	g_free(finalstring);
-	html_diag_destroy_cb(NULL, NULL, dg);
+	html_diag_destroy_cb(NULL, dg);
 }
 
 static void tabledatadialogok_lcb(GtkWidget * widget, Thtml_diag *dg) {
@@ -337,7 +336,7 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	alignlist = g_list_insert(alignlist, "justify", 3);
 	dg->combo[1] = combo_with_popdown_sized(tagvalues[1], alignlist, 1, 80);
 	g_list_free(alignlist);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Align")), 0, 1, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("Ali_gn:"), dg->combo[1], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[1])), 1, 2, 0, 1);
 
   alignlist = NULL;
@@ -351,59 +350,59 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	dg->combo[2] = combo_with_popdown_sized(tagvalues[4], alignlist, 1, 90);
 	g_list_free(alignlist);
 
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("VAlign")), 0, 1, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[2])), 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[8], main_v->current_project.classlist, 1, 80);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Class")), 0, 1, 2, 3);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[8], recent_attribs.classlist, 1, 80);
+	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[4])), 1, 2, 2, 3);
 
 	dg->entry[2] = entry_with_text(tagvalues[9], 512);
 	var_but = style_but_new(dg->entry[2], dg->dialog);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Style")), 0, 1, 3, 4);
+	bf_mnemonic_label_tad_with_alignment(_("St_yle:"), dg->entry[2], 0, 0.5, dgtable, 0, 1, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[2], 1, 6, 3, 4);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), var_but, 6, 7, 3, 4);
 
 	dg->entry[1] = entry_with_text(custom, 1024);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Custom")), 0, 1, 4, 5);
+	bf_mnemonic_label_tad_with_alignment(_("Custo_m:"), dg->entry[1], 0, 0.5, dgtable, 0, 1, 4, 5);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->entry[1], 1, 7, 4, 5);
 
 	dg->spin[5] = spinbut_with_value(tagvalues[2], 0, 10, 1.0, 2.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Col Span")), 2, 3, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("Co_l Span:"), dg->spin[5], 1, 0.5, dgtable, 2, 3, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[5], 3, 4, 0, 1);
 
 	dg->spin[4] = spinbut_with_value(tagvalues[5], 0, 100, 1.0, 5.0);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Row Span")), 2, 3, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Row Span:"), dg->spin[4], 1, 0.5, dgtable, 2, 3, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[4], 3, 4, 1, 2);
 
 	dg->check[1] = gtk_check_button_new();
 	parse_existence_for_dialog(tagvalues[7], dg->check[1]);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("No Wrap")), 2, 3, 2, 3);
+	bf_mnemonic_label_tad_with_alignment(_("No Wra_p:"), dg->check[1], 1, 0.5, dgtable, 2, 3, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[1], 3, 4, 2, 3);
 	
 	dg->spin[1] = spinbut_with_value(NULL, 0, 100, 1.0, 5.0);
 	dg->check[2] = gtk_check_button_new_with_label("%");
 	parse_integer_for_dialog(tagvalues[0], dg->spin[1], NULL, dg->check[2]);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Width")), 4, 5, 0, 1);
+	bf_mnemonic_label_tad_with_alignment(_("_Width:"), dg->spin[1], 1, 0.5, dgtable, 4, 5, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[1], 5, 6, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[2], 6, 7, 0, 1);
 
 	dg->spin[3] = spinbut_with_value(NULL, 0, 100, 1.0, 5.0);
 	dg->check[3] = gtk_check_button_new_with_label("%");
 	parse_integer_for_dialog(tagvalues[3], dg->spin[3], NULL, dg->check[3]);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Height")), 4, 5, 1, 2);
+	bf_mnemonic_label_tad_with_alignment(_("_Height:"), dg->spin[3], 1, 0.5, dgtable, 4, 5, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[3], 5, 6, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[3], 6, 7, 1, 2);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[6], main_v->current_project.colorlist, 1, 80);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), gtk_label_new(_("Background Color")), 4, 5, 2, 3);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[6], recent_attribs.colorlist, 1, 80);
+	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 1, 0.5, dgtable, 4, 5, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 5, 6, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog)), 6, 7, 2, 3);
 
 	if (type == 1) {
-		html_diag_finish(dg, tabledatadialogok_lcb);
+		html_diag_finish(dg, G_CALLBACK(tabledatadialogok_lcb));
 	} else {
-		html_diag_finish(dg, tableheaddialogok_lcb);
+		html_diag_finish(dg, G_CALLBACK(tableheaddialogok_lcb));
 	}
 
 	if (custom)	g_free(custom);
